@@ -112,11 +112,19 @@ sub choose_videos {
             }
             $data->{$ex}{$up}{$id}{from_list} = 1;
             my $line = '';
-            $line .= sprintf "%*s | ", $id_w,   $id                                 if $opt->{show_video_id};
-            $line .= sprintf "%*s  ",  $duration_w,   $data->{$ex}{$up}{$id}{duration}    // '' if $has_duration;
-            $line .= sprintf "%*s  ", $upload_date_w, $data->{$ex}{$up}{$id}{upload_date} // '' if $has_upload_date;
-            $line .= sprintf "%*s  ", $view_count_w,  $data->{$ex}{$up}{$id}{view_count}  // '' if $has_view_count && ( $opt->{list_sort_item} eq 'view_count_raw' || $opt->{show_view_count} );
-            $line .= sprintf "%s",  $title;
+            $line .= sprintf "%*s | ", $id_w, $id if $opt->{show_video_id};
+            if ( $opt->{entries_with_info} ) {
+                $line .= sprintf "%*s  ",  $duration_w,   $data->{$ex}{$up}{$id}{duration}    // '' if $has_duration;
+                $line .= sprintf "%*s  ", $upload_date_w, $data->{$ex}{$up}{$id}{upload_date} // '' if $has_upload_date;
+                $line .= sprintf "%*s  ", $view_count_w,  $data->{$ex}{$up}{$id}{view_count}  // '' if $has_view_count && ( $opt->{list_sort_item} eq 'view_count_raw' || $opt->{show_view_count} );
+            }
+            else {
+                if ( $has_view_count + $has_duration + $has_upload_date ) {
+                    $prompt .= '_';
+                    # it was never meant to get here
+                }
+            }
+            $line .= sprintf "%s", $title;
             push @str_videos, $line;
             push @avail_ids, $id;
             $index++;
