@@ -115,7 +115,7 @@ sub download {
 
     EXTRACTOR_KEY: for my $ex ( sort keys %$data ) {
 
-        UPLOADER_URL: for my $up ( sort keys %{$data->{$ex}} ) {
+        UPLOADER_ID: for my $up ( sort keys %{$data->{$ex}} ) {
             if ( ! @{$chosen->{$ex}{$up}} ) {
                 next;
             }
@@ -151,10 +151,7 @@ sub download {
                 if ( $qty eq 'manually' ) {
                     if ( $ask_fmt_for_each_video || ! $fmt_str ) {
                         my $count_of_total = $data->{$ex}{$up}{$id}{count} . '/' . $total;
-                        my $title;
-                        #if ( $ask_fmt_for_each_video ) {
-                            $title = "\n" . $count_of_total . ' "' . $data->{$ex}{$up}{$id}{title} . '"';
-                        #}
+                        my $title = "\n" . $count_of_total . ' "' . $data->{$ex}{$up}{$id}{title} . '"';
                         $fmt_str = _choose_fmt( $data, $ex, $up, $id, $title );
                         if ( ! defined $fmt_str ) {
                             print $count_of_total . ' skipped' . "\n";
